@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2019 Edgewall Software
+# Copyright (C) 2003-2020 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # All rights reserved.
 #
@@ -55,6 +55,9 @@ class TicketFieldList(list):
     def __deepcopy__(self, memo):
         return TicketFieldList(copy.deepcopy(value, memo) for value in self)
 
+    def __contains__(self, name):
+        return name in self._map
+
 
 class ITicketActionController(Interface):
     """Extension point interface for components willing to participate
@@ -166,14 +169,14 @@ class ITicketManipulator(Interface):
         compatibility."""
 
     def validate_ticket(req, ticket):
-        """Validate a ticket after it's been populated from user input.
+        """Validate ticket properties when creating or modifying.
 
         Must return a list of `(field, message)` tuples, one for each problem
         detected. `field` can be `None` to indicate an overall problem with the
         ticket. Therefore, a return value of `[]` means everything is OK."""
 
-    def validate_comment(self, comment):
-        """Validate ticket comment.
+    def validate_comment(req, comment):
+        """Validate ticket comment when appending or editing.
 
         Must return a list of messages, one for each problem detected.
         The return value `[]` indicates no problems.
