@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2004-2019 Edgewall Software
+# Copyright (C) 2004-2020 Edgewall Software
 # Copyright (C) 2004-2005 Christopher Lenz <cmlenz@gmx.de>
 # Copyright (C) 2005-2007 Christian Boos <cboos@edgewall.org>
 # All rights reserved.
@@ -31,7 +31,7 @@ from trac.resource import Resource
 from trac.ticket.api import TicketSystem, translation_deactivated
 from trac.ticket.model import Milestone, _datetime_to_db_str
 from trac.ticket.roadmap import group_milestones
-from trac.util import Ranges, as_bool
+from trac.util import Ranges, as_bool, as_int
 from trac.util.datefmt import (datetime_now, from_utimestamp,
                                format_date_or_datetime, parse_date,
                                to_timestamp, to_utimestamp, utc, user_time)
@@ -937,7 +937,7 @@ class QueryModule(Component):
 
     def process_request(self, req):
         req.perm(self.realm).assert_permission('TICKET_VIEW')
-        report_id = req.args.get('report')
+        report_id = req.args.as_int('report')
         if report_id:
             req.perm('report', report_id).assert_permission('REPORT_VIEW')
 
@@ -1153,10 +1153,11 @@ class QueryModule(Component):
             data['report_href'] = req.href.report()
             add_ctxtnav(req, _("Available Reports"), req.href.report())
             add_ctxtnav(req, _("New Custom Query"), req.href.query())
-            if query.id:
+            report_id = as_int(query.id, None)
+            if report_id is not None:
                 for title, description in self.env.db_query("""
                         SELECT title, description FROM report WHERE id=%s
-                        """, (query.id,)):
+                        """, (report_id,)):
                     data['report_resource'] = report_resource
                     data['description'] = description
         else:
