@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2003-2019 Edgewall Software
+# Copyright (C) 2003-2020 Edgewall Software
 # Copyright (C) 2003-2005 Jonas Borgström <jonas@edgewall.com>
 # All rights reserved.
 #
@@ -33,7 +33,7 @@ from trac.resource import (
 )
 from trac.search import ISearchSource, search_to_sql, shorten_result
 from trac.ticket import model
-from trac.ticket.api import TicketSystem, ITicketManipulator
+from trac.ticket.api import TicketSystem, ITicketManipulator, TicketFieldList
 from trac.ticket.notification import TicketChangeEvent
 from trac.ticket.roadmap import group_milestones
 from trac.timeline.api import ITimelineEventProvider
@@ -557,6 +557,7 @@ class TicketModule(Component):
         fields = self._prepare_fields(req, ticket)
 
         data['fields'] = fields
+        # fields_map is deprecated and removed in 1.5.1
         data['fields_map'] = {field['name']: i
                               for i, field in enumerate(fields)}
 
@@ -1330,7 +1331,7 @@ class TicketModule(Component):
         # Validate custom rules.
         comment = comment or req.args.get('edited_comment')
         for manipulator in self.ticket_manipulators:
-            if hasattr(manipulator, 'validate_comment'):
+            if ticket.exists and hasattr(manipulator, 'validate_comment'):
                 for message in manipulator.validate_comment(req, comment):
                     valid = False
                     add_warning(req, tag_("The ticket comment is invalid: "
@@ -1518,7 +1519,7 @@ class TicketModule(Component):
 
     def _prepare_fields(self, req, ticket, field_changes=None):
         context = web_context(req, ticket.resource)
-        fields = []
+        fields = TicketFieldList()
         for field in ticket.fields:
             name = field['name']
             type_ = field['type']
@@ -1646,6 +1647,7 @@ class TicketModule(Component):
         # -- Ticket fields
 
         fields = self._prepare_fields(req, ticket, field_changes)
+        # fields_map is deprecated and removed in 1.5.1
         fields_map = {field['name']: i for i, field in enumerate(fields)}
 
         # -- Ticket Change History
@@ -1741,7 +1743,8 @@ class TicketModule(Component):
                     class_=chrome.author_class(req, user))
         data.update({
             'context': context, 'conflicts': conflicts,
-            'fields': fields, 'fields_map': fields_map,
+            'fields': fields,
+            'fields_map': fields_map,  # deprecated and removed in 1.5.1
             'changes': changes, 'replies': replies,
             'attachments': AttachmentModule(self.env).attachment_data(context),
             'action_controls': action_controls, 'action': selected_action,
