@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2005-2019 Edgewall Software
+# Copyright (C) 2005-2020 Edgewall Software
 # Copyright (C) 2005-2006 Christopher Lenz <cmlenz@gmx.de>
 # All rights reserved.
 #
@@ -1002,13 +1002,13 @@ class Chrome(Component):
 
         files = {}
         # Collect templates list
-        site_templates = list_dir(self.env.templates_dir, '.html')
-        shared_templates = list_dir(Chrome(self.env).shared_templates_dir,
-                                    '.html')
+        exts = ('.html', '.txt')
+        site_templates = list_dir(self.env.templates_dir, exts)
+        shared_templates = list_dir(self.shared_templates_dir, exts)
 
         # Collect static resources list
         site_htdocs = list_dir(self.env.htdocs_dir)
-        shared_htdocs = list_dir(Chrome(self.env).shared_htdocs_dir)
+        shared_htdocs = list_dir(self.shared_htdocs_dir)
 
         if any((site_templates, shared_templates, site_htdocs, shared_htdocs)):
             files = {
@@ -1257,7 +1257,9 @@ class Chrome(Component):
                     label = absolute
                 elif req.lc_time == 'iso8601':
                     label = _("at %(iso8601)s", iso8601=absolute)
-                else:
+                elif format == 'date':
+                    label = _("on %(date)s", date=absolute)
+                else:  # format == 'datetime'
                     label = _("on %(date)s at %(time)s",
                               date=user_time(req, format_date, date),
                               time=user_time(req, format_time, date))
